<?php
/**
 * 2010-2021 WeLoveCustomers
 *
 * NOTICE OF LICENSE
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    WeLoveCustomers <hello@welovecustomers.fr>
 *  @copyright 2016-2022 WeLoveCustomers
 */
if (!defined('_PS_VERSION_')) {
    exit;
}

require_once dirname(__FILE__)."/Service/WLCConfig.php";
require_once dirname(__FILE__)."/Endpoint/BaseEndpoint.php";
require_once dirname(__FILE__)."/Service/Factory.php";
foreach (glob(dirname(__FILE__)."/controllers/front/*.php") as $filename) {
    require_once($filename) ;
}

class Wlcreferral extends Module
{
    protected $config_form = false;
    private $endpoint;
    private $factory;

    public function __construct()
    {
        $this->endpoint = new BaseEndpoint();
        $this->factory = new Factory();

        $this->name = 'wlcreferral';
        $this->tab = 'advertising_marketing';
        $this->version = '2.2.2.2';
        $this->author = 'WeLoveCustomers';
        $this->need_instance = 1;
        $this->ps_versions_compliancy = array('min' => '1.5.3', 'max' => _PS_VERSION_);
        $this->debug = false;
        //$this->module_key='';

        /**
         * Set $this->bootstrap to true if your module is compliant with bootstrap (PrestaShop 1.6)
         */
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('Referral new program by We Love Customers');
        $this->description = $this->l('Add a new referral program to your website');

        $this->confirmUninstall = $this->l('Are you sure you want to uninstall referral program module ?');

    }

    /**
     * Don't forget to create update methods if needed:
     * http://doc.prestashop.com/display/PS16/Enabling+the+Auto-Update
     */
    public function install()
    {
        // on ajoute les url de l'api
        $this->insertApiUrl();

        Configuration::updateValue(WLCConfig::GetPrefixKey('KEY'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('GLUE'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('TITLE'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('COLOR'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('HEADER_COLOR'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('BG_COLOR'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('HEADER_BG_COLOR'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('ICON'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('STATUS'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('POSITION'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('SPECIFIC_PROMPT'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('CORNER_BOX'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('ACCOUNT_BOX'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('POSTPURCHASE_BOX'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('DETAILORDER_BOX'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('MEMBERSHIP_WIDGET'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('MULTILINGUAL'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('LAST_CHECK_COUPONS'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('STYLE'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('FREE_GIFT_FOR_FRIEND'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('LOYALTY_WIDGET_CONFIG'), false);
        Configuration::updateValue(WLCConfig::GetPrefixKey('LOYALTY_BOX'), false);

        Configuration::updateValue(WLCConfig::GetPrefixKey('ID_FIRST_CUSTOMER_TO_SEND'), false);

        $hookRegistration =
                parent::install() &&
                $this->registerHook('displayFooter') &&
                $this->registerHook('actionPaymentConfirmation') &&
                $this->registerHook('displayOrderConfirmation') &&
                $this->registerHook('displayOrderDetail') &&
                $this->registerHook('displayCustomerAccount') &&
                $this->registerHook('displayAdminAfterHeader');

        if (_PS_VERSION_ >= '1.7'){
            $hookRegistration == $hookRegistration && $this->registerHook('filterCmsContent');
        }



        return $hookRegistration;
    }

    /**
     * Retourne la liste des urls nécessaire à l'api
     * @return array
     */
    private function getApiUrl() {
        return array(
            'module-wlcreferral-config' => 'wlc/config/check',
            'module-wlcreferral-addoffer' => 'wlc/offer/add',
            'module-wlcreferral-removeoffer' => 'wlc/offer/remove'
        );
    }

    /**
     * Insert API Url on Database
     */
    private function insertApiUrl() {
        $db = Db::GetInstance();
        foreach($this->getApiUrl() as $page => $url) {

            $sql = 'SELECT id_meta FROM '._DB_PREFIX_.'meta WHERE page = "'.$page.'"';
            $metaId = $db->getValue($sql);

            // si la page n'existe pas on la crée
            if(!$metaId) {
                $response = $db->insert('meta', array(
                    'page' => $page
                ));

                $sql = 'SELECT id_meta FROM '._DB_PREFIX_.'meta WHERE page = "'.$page.'"';
                $metaId = $db->getValue($sql);
            }


            foreach(Language::getLanguages(true) as $language) {

                $sql = 'SELECT id_meta FROM '._DB_PREFIX_.'meta_lang WHERE url_rewrite = "'.$url.'" AND id_lang ='. $language['id_lang'];
                $metaLangId = $db->getValue($sql);

                // si l'url rewrite n'existe pas, on la crée
                if(!$metaLangId) {
                    $db->insert('meta_lang', array(
                        'id_meta' => $metaId,
                        'id_shop' => 1,
                        'id_lang' => $language['id_lang'],
                        'url_rewrite' => $url
                    ));
                }
            }
        }
    }


    public function uninstall()
    {
        Configuration::deleteByName(WLCConfig::GetPrefixKey('KEY'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('GLUE'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('TITLE'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('COLOR'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('HEADER_COLOR'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('BG_COLOR'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('HEADER_BG_COLOR'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('ICON'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('STATUS'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('POSITION'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('SPECIFIC_PROMPT'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('CORNER_BOX'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('ACCOUNT_BOX'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('POSTPURCHASE_BOX'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('DETAILORDER_BOX'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('MEMBERSHIP_WIDGET'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('MULTILINGUAL'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('LAST_CHECK_COUPONS'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('STYLE'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('FREE_GIFT_FOR_FRIEND'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('LOYALTY_WIDGET_CONFIG'));
        Configuration::deleteByName(WLCConfig::GetPrefixKey('LOYALTY_BOX'));

        return parent::uninstall();
    }

    
    /**
     * Load the configuration form
     */
    public function getContent()
    {
        /**
         * If values have been submitted in the form, process.
         */
        $validateForm = null;
        if (((bool)Tools::isSubmit('submitWeLoveCustomersModule')) == true) {
            $validateForm = $this->postProcess();
        }


        // generate new master codes if customer wants it
        $referralInfos = $this->referralInfos();
        $stats = $this->getStats();
        $lastPrestashopModuleVersion = false;
        if (WLCConfig::Get('KEY')){

            $response = $this->endpoint->doAuthRequest('prestashopPluginVersion');

            if ($response){
                $objResponse = json_decode($response);
                $lastPrestashopModuleVersion = $objResponse->version;
            }
        }

        $this->context->smarty->assign('module_dir', $this->_path);
        $this->context->smarty->assign(array('validateForm' => $validateForm));

        $this->context->smarty->assign('weLoveCustomersUrl', 'http://www.welovecustomers.fr/developpez-le-parrainage-en-e-commerce/?utm_campaign=install-plugin&utm_source=prestashop&utm_medium='.$this->version.'&utm_term='._PS_BASE_URL_);
        $this->context->smarty->assign('pluginVersion', $this->version);
        $this->context->smarty->assign('currentBackofficeUrl', $_SERVER['REQUEST_URI']);
        $this->context->smarty->assign('lastPrestashopModuleVersion', $lastPrestashopModuleVersion);

        $masterOfferValue = $masterOfferValueType = false;
        $slaveOfferValue = $slaveOfferValueType = false;
        if ($referralInfos != false){
            if ($referralInfos['masterOfferValueType'] == 'percent'){
                $masterOfferValue = $referralInfos['masterOfferValue'];
                $masterOfferValueType = '%';
            } else if ($referralInfos['masterOfferValueType'] == 'amount'){
                $masterOfferValue =  $referralInfos['masterOfferValue'];
                $masterOfferValueType =  '€';
            } else if ($referralInfos['masterOfferValueType'] == 'shipping'){
                $masterOfferValue = 'Free shipping';
            }
            if ($referralInfos['slaveOfferValueType'] == 'percent'){
                $slaveOfferValue = $referralInfos['slaveOfferValue'];
                $slaveOfferValueType = '%';
            } else if ($referralInfos['slaveOfferValueType'] == 'amount'){
                $slaveOfferValue = $referralInfos['slaveOfferValue'];
                $slaveOfferValueType = '€';
            } else if ($referralInfos['slaveOfferValueType'] == 'shipping'){
                $slaveOfferValue = 'Free shipping';
            }
        }

        $this->context->smarty->assign('masterOfferValue', $masterOfferValue);
        $this->context->smarty->assign('masterOfferValueType', $masterOfferValueType);
        $this->context->smarty->assign('slaveOfferValue', $slaveOfferValue);
        $this->context->smarty->assign('slaveOfferValueType', $slaveOfferValueType);

        $this->context->smarty->assign('countMasterAvailableCodes', $this->countAvailableCodes($referralInfos['masterOfferId'], 'coupon'));
        $this->context->smarty->assign('countContactAvailableCodes', $this->countAvailableCodes($referralInfos['masterOfferId'], 'contact'));
        $this->context->smarty->assign('countSlaveAvailableCodes', $this->countAvailableCodes($referralInfos['slaveOfferId'], 'coupon'));

        $this->context->smarty->assign('scoreNPS', $this->nps());

        $this->context->smarty->assign('debug', $this->debug);

        if($stats) {
            $this->context->smarty->assign('invitations', $stats->contact);
            $this->context->smarty->assign('rewards', $stats->father);
            $this->context->smarty->assign('welcomes', $stats->slave);
        } else {
            $this->context->smarty->assign('invitations', "-");
            $this->context->smarty->assign('rewards', "-");
            $this->context->smarty->assign('welcomes', "-");
        }

        $output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

        return $output . $this->renderForm();

    }

    /**
     * Create the form that will be displayed in the configuration of your module.
     */
    protected function renderForm()
    {
        $helper = new HelperForm();

        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->module = $this;
        $helper->default_form_language = $this->context->language->id;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

        $helper->identifier = $this->identifier;
        $helper->submit_action = 'submitWeLoveCustomersModule';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
            .'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');


        $helper->tpl_vars = array(
            'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id,
        );

        // added for PS 1.5.x
        $helper->fields_value = $this->getConfigFormValues();

        return $helper->generateForm(array($this->getConfigForm()));
    }

    /**
     * Create the structure of your form.
     */
    protected function getConfigForm()
    {

        $options = array(
                  array(
                    'id_option' => 0,
                    'name' => $this->l('Disabled')
                  ),array(
                    'id_option' => 1,
                    'name' => $this->l('Enabled')
                  ),
        );

        $statuses = array(
                  array(
                    'id_option' => 'extended',
                    'name' => $this->l('Extended')
                  ),
                  array(
                    'id_option' => 'collapsed',
                    'name' => $this->l('Collapsed')
                  ),
        );
        $positions = array(
                  array(
                    'id_option' => 'bottom-right',
                    'name' => $this->l('Bottom right')
                  ),
                  array(
                    'id_option' => 'top-right',
                    'name' => $this->l('Top right')
                  )
        );
        $styles = array(
                  array(
                    'id_option' => 'basic',
                    'name' => $this->l('Basic')
                  ),
                  array(
                    'id_option' => 'minimal',
                    'name' => $this->l('Minimal')
                  ),
        );
        $icons = array(
                  array(
                    'id_option' => 'gift',
                    'name' => $this->l('gift')
                  ),
                  array(
                    'id_option' => 'cash',
                    'name' => $this->l('cash')
                  ),
                  array(
                    'id_option' => 'rocket',
                    'name' => $this->l('rocket')
                  ),
                  array(
                    'id_option' => 'heart',
                    'name' => $this->l('heart')
                  ),
                  array(
                    'id_option' => 'share',
                    'name' => $this->l('share')
                  ),
                  array(
                    'id_option' => 'discount',
                    'name' => $this->l('discount')
                  ),
                  array(
                    'id_option' => 'like',
                    'name' => $this->l('like')
                  ),
                  array(
                    'id_option' => 'reward',
                    'name' => $this->l('reward')
                  ),
                  array(
                    'id_option' => 'euro',
                    'name' => $this->l('euro')
                  ),
                  array(
                    'id_option' => 'euro2',
                    'name' => $this->l('euro2')
                  ),
                  array(
                    'id_option' => 'dollar',
                    'name' => $this->l('dollar')
                  ),
                  array(
                    'id_option' => 'icecream',
                    'name' => $this->l('icecream')
                  ),
                  array(
                    'id_option' => 'plant',
                    'name' => $this->l('plant')
                  ),
                  array(
                    'id_option' => 'white-gift',
                    'name' => $this->l('white-gift')
                  )
        );
        return array(
            'form' => array(
                'legend' => array(
                'title' => $this->l('Settings'),
                'icon' => 'icon-cogs',
                ),
                'input' => array(
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-key"></i>',
                        'desc' => $this->l('Enter your key'),
                        'name' => WLCConfig::GetPrefixKey('KEY'),
                        'label' => $this->l('WeLoveCustomers key'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-lock"></i>',
                        'desc' => $this->l('Enter glue'),
                        'name' => WLCConfig::GetPrefixKey('GLUE'),
                        'label' => $this->l('WeLoveCustomers glue'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable corner box widget'),
                        'name' => WLCConfig::GetPrefixKey('CORNER_BOX'),
                        'label' => $this->l('Corner widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Select widget status'),
                        'name' => WLCConfig::GetPrefixKey('STATUS'),
                        'label' => $this->l('Corner widget status'),
                        'options' => array(
                            'query' => $statuses,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-th"></i>',
                        'desc' => $this->l('Select widget position'),
                        'name' => WLCConfig::GetPrefixKey('POSITION'),
                        'label' => $this->l('Corner widget position'),
                        'options' => array(
                            'query' => $positions,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable post purchase box widget'),
                        'name' => WLCConfig::GetPrefixKey('POSTPURCHASE_BOX'),
                        'label' => $this->l('Post purchase widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable detail order box widget'),
                        'name' => WLCConfig::GetPrefixKey('DETAILORDER_BOX'),
                        'label' => $this->l('Detail order widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable account page widget'),
                        'name' => WLCConfig::GetPrefixKey('ACCOUNT_BOX'),
                        'label' => $this->l('Account page widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable membership widget'),
                        'name' => WLCConfig::GetPrefixKey('MEMBERSHIP_WIDGET'),
                        'label' => $this->l('Membership widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-info"></i>',
                        'desc' => $this->l('Enter title'),
                        'name' => WLCConfig::GetPrefixKey('TITLE'),
                        'label' => $this->l('Widget title'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-image"></i>',
                        'desc' => $this->l('Choose icon'),
                        'name' => WLCConfig::GetPrefixKey('ICON'),
                        'label' => $this->l('Widget icon'),
                        'options' => array(
                            'query' => $icons,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),

                    array(
                        'col' => 3,
                        'type' => 'color',
                        'prefix' => '<i class="icon icon-tint"></i>',
                        'desc' => $this->l('Choose text color'),
                        'name' => WLCConfig::GetPrefixKey('COLOR'),
                        'label' => $this->l('Widget text color')
                    ),
                    array(
                        'col' => 3,
                        'type' => 'color',
                        'prefix' => '<i class="icon icon-tint"></i>',
                        'desc' => $this->l('Choose header color'),
                        'name' => WLCConfig::GetPrefixKey('HEADER_COLOR'),
                        'label' => $this->l('Widget header color')
                    ),
                    array(
                        'col' => 3,
                        'type' => 'color',
                        'prefix' => '<i class="icon icon-tint"></i>',
                        'desc' => $this->l('Choose background color'),
                        'name' => WLCConfig::GetPrefixKey('BG_COLOR'),
                        'label' => $this->l('Widget background color')
                    ),
                    array(
                        'col' => 3,
                        'type' => 'color',
                        'prefix' => '<i class="icon icon-tint"></i>',
                        'desc' => $this->l('Choose header background color'),
                        'name' => WLCConfig::GetPrefixKey('HEADER_BG_COLOR'),
                        'label' => $this->l('Widget header background color')
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-filter"></i>',
                        'desc' => $this->l('Widget style'),
                        'name' => WLCConfig::GetPrefixKey('STYLE'),
                        'label' => $this->l('Widget style'),
                        'options' => array(
                            'query' => $styles,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-plus"></i>',
                        'desc' => $this->l('Enter specific prompt'),
                        'name' => WLCConfig::GetPrefixKey('SPECIFIC_PROMPT'),
                        'label' => $this->l('Widget specific prompt'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-gift"></i>',
                        'desc' => $this->l('Enter ID of free gift product'),
                        'name' => WLCConfig::GetPrefixKey('FREE_GIFT_FOR_FRIEND'),
                        'label' => $this->l('Free gift for invited friend'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-power-off"></i>',
                        'desc' => $this->l('Enable account page loyalty widget'),
                        'name' => WLCConfig::GetPrefixKey('LOYALTY_BOX'),
                        'label' => $this->l('Account page loyalty widget'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    ),
                    array(
                        'col' => 3,
                        'type' => 'text',
                        'prefix' => '<i class="icon icon-cog"></i>',
                        'desc' => $this->l('Enter loyalty widget configuration code'),
                        'name' => WLCConfig::GetPrefixKey('LOYALTY_WIDGET_CONFIG'),
                        'label' => $this->l('Loyalty widget configuration'),
                    ),
                    array(
                        'col' => 3,
                        'type' => 'select',
                        'prefix' => '<i class="icon icon-public"></i>',
                        'desc' => $this->l('Enable multilingual referral'),
                        'name' => WLCConfig::GetPrefixKey('MULTILINGUAL'),
                        'label' => $this->l('Multilingual ecommerce referral'),
                        'options' => array(
                            'query' => $options,
                            'id' => 'id_option',
                            'name' => 'name'
                          )
                    )
                ),
                'submit' => array(
                    'title' => $this->l('Save')
                ),
            ),
        );
    }


    /**
     * Set values for the inputs.
     */
    protected function getConfigFormValues()
    {
        return array(
            WLCConfig::GetPrefixKey('KEY') => WLCConfig::Get('KEY'),
            WLCConfig::GetPrefixKey('GLUE') => WLCConfig::Get('GLUE'),
            WLCConfig::GetPrefixKey('TITLE') => WLCConfig::Get('TITLE'),
            WLCConfig::GetPrefixKey('COLOR') => WLCConfig::Get('COLOR'),
            WLCConfig::GetPrefixKey('BG_COLOR') => WLCConfig::Get('BG_COLOR'),
            WLCConfig::GetPrefixKey('HEADER_COLOR') => WLCConfig::Get('HEADER_COLOR'),
            WLCConfig::GetPrefixKey('HEADER_BG_COLOR') => WLCConfig::Get('HEADER_BG_COLOR'),
            WLCConfig::GetPrefixKey('ICON') => WLCConfig::Get('ICON'),
            WLCConfig::GetPrefixKey('STATUS') => WLCConfig::Get('STATUS'),
            WLCConfig::GetPrefixKey('POSITION') => WLCConfig::Get('POSITION'),
            WLCConfig::GetPrefixKey('SPECIFIC_PROMPT') => WLCConfig::Get('SPECIFIC_PROMPT'),
            WLCConfig::GetPrefixKey('CORNER_BOX') => WLCConfig::Get('CORNER_BOX'),
            WLCConfig::GetPrefixKey('ACCOUNT_BOX') => WLCConfig::Get('ACCOUNT_BOX'),
            WLCConfig::GetPrefixKey('POSTPURCHASE_BOX') => WLCConfig::Get('POSTPURCHASE_BOX'),
            WLCConfig::GetPrefixKey('DETAILORDER_BOX') => WLCConfig::Get('DETAILORDER_BOX'),
            WLCConfig::GetPrefixKey('MEMBERSHIP_WIDGET') => WLCConfig::Get('MEMBERSHIP_WIDGET'),
            WLCConfig::GetPrefixKey('MULTILINGUAL') => WLCConfig::Get('MULTILINGUAL'),
            WLCConfig::GetPrefixKey('LAST_CHECK_COUPONS') => WLCConfig::Get('LAST_CHECK_COUPONS'),
            WLCConfig::GetPrefixKey('STYLE') => WLCConfig::Get('STYLE'),
            WLCConfig::GetPrefixKey('FREE_GIFT_FOR_FRIEND') => WLCConfig::Get('FREE_GIFT_FOR_FRIEND'),
            WLCConfig::GetPrefixKey('LOYALTY_WIDGET_CONFIG') => WLCConfig::Get('LOYALTY_WIDGET_CONFIG'),
            WLCConfig::GetPrefixKey('LOYALTY_BOX') => WLCConfig::Get('LOYALTY_BOX')
        );
    }

    /**
     * Save form data.
     */
    protected function postProcess()
    {
        $res = true;
        $form_values = $this->getConfigFormValues();
        foreach (array_keys($form_values) as $key) {
            $res = $res && Configuration::updateValue($key, Tools::getValue($key));
        }
        return $res;
    }

    /**
     *  shortcodes hook
     */
    public function hookFilterCmsContent($params){
        $params['object']['content'] = $this->updateContent($params['object']['content']);
        return [
            'object' => $params['object']
        ];
    }

    public function updateContent($content){
        $content = urldecode($content);

        //getting overload of shortcode wlc_box
        $overload = $this->between('{{wlc_box', '}}', $content);
        $overload = str_replace('#', '', $overload);
        $overloadParam = $this->getOverloadParam($overload);
        //sending overload to display
        $boxWidget = $this->displayWLCBox($overloadParam);
        //return display of shortcode
        $content = preg_replace('#{{wlc_box'.$overload.'}}#',$boxWidget,$content);

        //getting overload of shortcode wlc_dashboard
        $overload = $this->between('{{wlc_dashboard', '}}', $content);
        $overload = str_replace('#', '', $overload);
        $overloadParam = $this->getOverloadParam($overload);
        $dashboardWidget = $this->displayCustomerDashboard($overloadParam['bgColor'], $overloadParam['headerColor'], $overloadParam['headerBgColor'], $overloadParam['image'], $overloadParam['title']);
        $content = preg_replace('#{{wlc_dashboard'.$overload.'}}#',$dashboardWidget,$content);


        $loyaltyWidget = $this->displayWLCLoyaltyBox($overloadParam);
        //return display of shortcode
        $content = preg_replace('#{{wlc_loyalty'.$overload.'}}#',$loyaltyWidget,$content);


        return $content;
    }

    //getting all overload parameters and returning it to updateContent
    public function getOverloadParam($overload){
        $param = array(
                'color'       => false,
                'bgColor'       => false,
                'headerColor'   => false,
                'headerBgColor' => false,
                'image'         => false,
                'title'         => false
        );
        if (stripos($overload, 'color')){
            $param['color'] = $this->between(' color:"', '"', $overload);
            if ($param['color'] == false){
                $param['color'] = $this->between(' color="', '"', $overload);
            }
        }
        if (stripos($overload, 'color-background')){
            $param['bgColor'] = $this->between(' color-background:"', '"', $overload);
            if ($param['bgColor'] == false){
                $param['bgColor'] = $this->between(' color-background="', '"', $overload);
            }
        }
        if (stripos($overload, 'header-color')){
            $param['headerColor'] = $this->between(' header-color:"', '"', $overload);
            if ($param['headerColor'] == false){
                $param['headerColor'] = $this->between(' header-color="', '"', $overload);
            }
        }
        if (stripos($overload, 'header-background-color')){
            $param['headerBgColor'] = $this->between(' header-background-color:"', '"', $overload);
            if ($param['headerBgColor'] == false){
                $param['headerBgColor'] = $this->between(' header-background-color="', '"', $overload);
            }
        }
        if (stripos($overload, 'image')){
            $image = $this->between(' image:"', '"', $overload);
            if ($image == false){
                $image = $this->between(' image="', '"', $overload);
            }
            if ($image == 'cash' || $image == 'share' || $image == 'gift' || $image == 'heart' || $image == 'like' || $image == 'rocket' || $image == 'reward' || $image == 'discount' || $image == 'dollar' || $image == 'euro' || $image == 'euro2' || $image == 'icecream' || $image == 'plant' || $image == 'white-gift'){
                $param['image'] = $image;
            }
        }
        if (stripos($overload, 'title')){
            $param['title'] = $this->between(' title:"', '"', $overload);
            if ($param['title'] == false){
                $param['title'] = $this->between(' title="', '"', $overload);
            }
        }

        return $param;
    }

    public function between($string1, $string2, $content)
    {
        return $this->before($string2, $this->after($string1, $content));
    }

    public function before($string1, $content)
    {
        return substr($content, 0, strpos($content, $string1));
    }

    public function after($string1, $content)
    {
        if (!is_bool(strpos($content, $string1)))
        return substr($content, strpos($content,$string1)+strlen($string1));
    }

    //assign parameters to wlc-box.tpl
    public function displayWLCBox($params){
        $html = false;
        $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));
        if ($params['title']){
            $this->context->smarty->assign('weLoveCustomersTitle', $params['title']);
        }else{
            $this->context->smarty->assign('weLoveCustomersTitle', WLCConfig::Get('TITLE'));
        }
        if ($params['color']){
            $this->context->smarty->assign('weLoveCustomersColor', $params['color']);
        }else{
            $this->context->smarty->assign('weLoveCustomersColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('COLOR')));
        }
        if ($params['bgColor']){
            $this->context->smarty->assign('weLoveCustomersBgColor', $params['bgColor']);
        }else{
            $this->context->smarty->assign('weLoveCustomersBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('BG_COLOR')));
        }
        if ($params['headerColor']){
            $this->context->smarty->assign('weLoveCustomersHeaderColor', $params['headerColor']);
        }else{
            $this->context->smarty->assign('weLoveCustomersHeaderColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_COLOR')));
        }
        if ($params['headerBgColor']){
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', $params['headerBgColor']);
        } else {
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_BG_COLOR')));
        }
        if ($params['image']){
            $this->context->smarty->assign('weLoveCustomersIcon', $params['image']);
        } else {
            $this->context->smarty->assign('weLoveCustomersIcon', WLCConfig::Get('ICON'));
        }



        $this->context->smarty->assign('customerName', $this->context->customer->lastname);
        $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

        $this->context->smarty->assign('customerEmail', $this->context->customer->email);
        $this->context->smarty->assign('weLoveCustomersLabel', '');
        $this->context->smarty->assign('weLoveCustomersUrl', '');
        $this->context->smarty->assign('weLoveCustomersStyle', WLCConfig::Get('STYLE'));
        $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/referralbox.tpl');

        return $html;
    }

    //assign parameters to dashboard.tpl
    public function displayCustomerDashboard($bgColor, $headerColor, $headerBgColor, $image, $title){
        $html = false;
        $this->context->smarty->assign('customerName', $this->context->customer->lastname);
        $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

        $this->context->smarty->assign('customerEmail', $this->context->customer->email);
        $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));

        if ($bgColor){
            $this->context->smarty->assign('weLoveCustomersBgColor', $bgColor);
        }else{
            $this->context->smarty->assign('weLoveCustomersBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('BG_COLOR')));
        }
        if ($headerColor){
            $this->context->smarty->assign('weLoveCustomersHeaderColor', $headerColor);
        }else{
            $this->context->smarty->assign('weLoveCustomersHeaderColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_COLOR')));
        }
        if ($headerBgColor){
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', $headerBgColor);
        }else{
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_BG_COLOR')));
        }
        if ($image){
            $this->context->smarty->assign('weLoveCustomersIcon', $image);
        }else{
            $this->context->smarty->assign('weLoveCustomersIcon', WLCConfig::Get('ICON'));
        }
        if ($title){
            $this->context->smarty->assign('weLoveCustomersTitle', $title);
        }else{
            $this->context->smarty->assign('weLoveCustomersTitle', WLCConfig::Get('TITLE'));
        }

        $this->context->smarty->assign('weLoveCustomersStyle', WLCConfig::Get('STYLE'));

        $this->context->smarty->assign('customerName', $this->context->customer->lastname);
        $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

        $this->context->smarty->assign('customerEmail', $this->context->customer->email);

        $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/dashboard.tpl');

        return $html;
    }


    //assign parameters to wlc-box.tpl
    public function displayWLCLoyaltyBox($params = false){
        $html = false;
        $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));

        $this->context->smarty->assign('widgetConfig', WLCConfig::Get('LOYALTY_WIDGET_CONFIG'));

        $this->context->smarty->assign('customerName', $this->context->customer->lastname);
        $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

        $this->context->smarty->assign('customerEmail', $this->context->customer->email);
        $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/loyaltybox.tpl');

        return $html;
    }



    public function hookDisplayFooter()
    {

        $html = false;
        if ((bool)WLCConfig::Get('CORNER_BOX')){

            $this->context->smarty->assign('customerName', $this->context->customer->lastname);
            $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

            $this->context->smarty->assign('customerEmail', $this->context->customer->email);


            $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));
            $this->context->smarty->assign('weLoveCustomersTitle', WLCConfig::Get('TITLE'));
            $sharpOutColor = WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('COLOR'));
            $this->context->smarty->assign('weLoveCustomersColor', $sharpOutColor);
            $sharpOutBG = WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('BG_COLOR'));
            $this->context->smarty->assign('weLoveCustomersBgColor', $sharpOutBG);
            $sharpOutHeader = WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_COLOR'));
            $this->context->smarty->assign('weLoveCustomersHeaderColor', $sharpOutHeader);
            $sharpOutHeaderBG = WLCConfig::GetSharpOut(WLCConfig::Get('HEADER_BG_COLOR'));
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', $sharpOutHeaderBG);

            $this->context->smarty->assign('weLoveCustomersIcon', WLCConfig::Get('ICON'));
            $this->context->smarty->assign('weLoveCustomersStatus', WLCConfig::Get('STATUS'));
            $this->context->smarty->assign('weLoveCustomersPosition', WLCConfig::Get('POSITION'));
            $this->context->smarty->assign('weLoveCustomersForce', WLCConfig::Get('MULTILINGUAL'));
            $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/referralcornerbox.tpl');
        }

        return $html;
    }
    
   


    public function hookDisplayOrderDetail($params){
        $html = false;
        if ((bool)WLCConfig::Get('DETAILORDER_BOX')){
            $html = $this->displaySharePurchaseWidget($params['order']);
        }
        return $html;
    }



    public function hookDisplayCustomerAccount($params){
        $html = false;
        if ((bool)WLCConfig::Get('MEMBERSHIP_WIDGET')
            ||(bool)WLCConfig::Get('ACCOUNT_BOX')
            ||(bool)WLCConfig::Get('LOYALTY_BOX')){
            $this->context->smarty->assign('customerName', $this->context->customer->lastname);
            $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

            $this->context->smarty->assign('customerEmail', $this->context->customer->email);

            $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));
            $this->context->smarty->assign('weLoveCustomersColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('COLOR')));
            $this->context->smarty->assign('weLoveCustomersBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('BG_COLOR')));
            $this->context->smarty->assign('weLoveCustomersHeaderColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_COLOR')));
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_BG_COLOR')));
            $this->context->smarty->assign('weLoveCustomersMembership', WLCConfig::Get('MEMBERSHIP_WIDGET'));
            $this->context->smarty->assign('weLoveCustomersAccountBox', WLCConfig::Get('ACCOUNT_BOX'));
            $this->context->smarty->assign('weLoveCustomersIcon', WLCConfig::Get('ICON'));

            $this->context->smarty->assign('weLoveCustomersLabel', '');
            $this->context->smarty->assign('weLoveCustomersUrl', '');

            $this->context->smarty->assign('weLoveCustomersTitle', WLCConfig::Get('TITLE'));

            $this->context->smarty->assign('weLoveCustomersLoyaltyBox', WLCConfig::Get('LOYALTY_BOX'));
            $this->context->smarty->assign('widgetConfig', WLCConfig::Get('LOYALTY_WIDGET_CONFIG'));

            $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/membership.tpl');
        }
        return $html;
    }

    private function displaySharePurchaseWidget($order = false, $forceDisplay = false){
        $html = false;
        if ((bool)WLCConfig::Get('POSTPURCHASE_BOX') || $forceDisplay){
            // getting order products
            $order = ($order)?new Order((int)$order->id):false;
            $products = ($order)?$order->getProducts():false;
            // get the first product to customize widget
            if ($products) {
                $firstProduct = array_shift($products);
                $product = new Product((int)($firstProduct['id_product']));

                $link = new Link();
                $url = $link->getProductLink($product->id);
                $productName = array_shift($product->name);

                if ($prompt = WLCConfig::Get('SPECIFIC_PROMPT')){
                    $prompt = sprintf($prompt, $productName);
                }
                $this->context->smarty->assign('weLoveCustomersLabel', $prompt);
                $this->context->smarty->assign('weLoveCustomersUrl', $url);
            } else {
                $this->context->smarty->assign('weLoveCustomersLabel', '');
                $this->context->smarty->assign('weLoveCustomersUrl', '');
            }




            $this->context->smarty->assign('customerName', $this->context->customer->lastname);
            $this->context->smarty->assign('customerFirstname', $this->context->customer->firstname);

            $this->context->smarty->assign('customerEmail', $this->context->customer->email);

            $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));
            $this->context->smarty->assign('weLoveCustomersTitle', WLCConfig::Get('TITLE'));
            $this->context->smarty->assign('weLoveCustomersColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('COLOR')));
            $this->context->smarty->assign('weLoveCustomersBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('BG_COLOR')));
            $this->context->smarty->assign('weLoveCustomersHeaderColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_COLOR')));
            $this->context->smarty->assign('weLoveCustomersHeaderBgColor', WLCConfig::GetColorCodeFromConfig(WLCConfig::GetPrefixKey('HEADER_BG_COLOR')));
            $this->context->smarty->assign('weLoveCustomersIcon', WLCConfig::Get('ICON'));
            $this->context->smarty->assign('weLoveCustomersStyle', WLCConfig::Get('STYLE'));
            $html .= $this->context->smarty->fetch($this->local_path.'views/templates/front/referralbox.tpl');
        }
        return $html;
    }


    /*
        Version 1.7 $params['order']
        Version 1.6 $params['objOrder']
    */
    public function hookDisplayOrderConfirmation($params){
        $html = false;
        $order = isset($params['objOrder'])?$params['objOrder']:(isset($params['order'])?$params['order']:false);
        if ($order){
            $html = $this->displayPurchaseWidget($order);
            if ((bool)WLCConfig::Get('POSTPURCHASE_BOX')){
                $html .= $this->displaySharePurchaseWidget($order);
            }
        }
        return $html;
    }
    private function getCouponsFromOrder($order){

        // getting coupon information
        $coupons = array();
        $cartRules = $order->getCartRules();
        foreach ($cartRules as $orderCartRule){
            $cartRule = new CartRule($orderCartRule['id_cart_rule']);
            $coupons[] = $cartRule->code;
        }
        return implode(',', $coupons);
    }

    private function displayPurchaseWidget($order){

        $html = false;


        // getting customer information
        $customerId = $order->id_customer;
        $customer = new Customer((int)($order->id_customer));
        $customerName =  $customer->lastname;

        $coupons = $this->getCouponsFromOrder($order);

        $orderId = ($order->id)?$order->id:$order->id_order;

        $controlKey = md5(
                            WLCConfig::Get('GLUE') .
                            $customerName .
                            $customer->email .
                            '' .
                            $order->total_paid_tax_excl .
                            $coupons .
                            time($order->date_add) .
                            $orderId
                        );

        $this->context->smarty->assign('weLoveCustomersKey', WLCConfig::Get('KEY'));
        $this->context->smarty->assign('weLoveCustomersDataName', $customerName);
        $this->context->smarty->assign('weLoveCustomersDataFirstname', $customer->firstname);
        $this->context->smarty->assign('weLoveCustomersDataEmail', $customer->email);
        $this->context->smarty->assign('weLoveCustomersDataMobile', '');
        $this->context->smarty->assign('weLoveCustomersDataAmount', $order->total_paid_tax_excl);
        $this->context->smarty->assign('weLoveCustomersDataCoupons', $coupons);
        $this->context->smarty->assign('weLoveCustomersDataTimestamp', time($order->date_add));
        $this->context->smarty->assign('weLoveCustomersDataPurchaseId', $orderId);
        $this->context->smarty->assign('weLoveCustomersDataControlKey', $controlKey);
        $html = $this->context->smarty->fetch($this->local_path.'views/templates/front/purchase.tpl');

        return $html;
    }

    public function hookActionPaymentConfirmation($params){

        /*
        array(
            'id_order' => (int) Order ID
        );
        */
        // call addbuyer
        // var_dump($params);
        $order = new Order((int)$params['id_order']);
        if ($order){
            // get customer information
            $customerId = $order->id_customer;
            $customer = new Customer((int)($order->id_customer));
            $customerName =  $customer->lastname;


            $coupons = $this->getCouponsFromOrder($order);

            $orderId = ($order->id)?$order->id:$order->id_order;
            $controlKey = md5(
                                WLCConfig::Get('GLUE') .
                                $customerName .
                                $customer->email .
                                '' .
                                $order->total_paid_tax_excl .
                                $coupons .
                                time($order->date_add) .
                                $orderId
                            );

            $langId = $customer->id_lang;
            $lang = new LanguageCore((int)$langId);
            $langCode = ($lang && $lang->iso_code)?$lang->iso_code:false;

            $callData = array (
                            'data-name' => $customerName,
                            'data-email' => $customer->email ,
                            'data-mobile' => '',
                            'data-amount' => $order->total_paid_tax_excl,
                            'data-coupons' => $coupons,
                            'data-timestamp' => time($order->date_add),
                            'data-purchase-id' => $orderId,
                            'data-hash' => $controlKey,
                            'data-lang' => $langCode,
                            'data-firstname' => $customer->firstname
                        );
            $this->endpoint->doAuthRequest('addBuyer', $callData);
        }
    }

   

    /*
     * getting all infos from referralInfos
     */
    public function referralInfos(){
        $offerInfos = false;
        $referralOfferInfos = false;

        $response = $this->endpoint->doAuthRequest('referralInfos');

        if ($response){
            $offerInfos = json_decode($response);
            if ($offerInfos->masterOffer){
                $referralOfferInfos['nameOffer1'] = $offerInfos->nameOffer1;
                $referralOfferInfos['masterOfferId'] = $offerInfos->masterOfferId;
                $referralOfferInfos['masterOfferValueType'] = $offerInfos->masterOffer->offerValueType;
                $referralOfferInfos['masterOfferValue'] = $offerInfos->masterOffer->offerValue;
            }
            if ($offerInfos->slaveOffer){
                $referralOfferInfos['nameOffer2'] = $offerInfos->nameOffer2;
                $referralOfferInfos['slaveOfferId'] = $offerInfos->slaveOfferId;
                $referralOfferInfos['slaveOfferValueType'] = $offerInfos->slaveOffer->offerValueType;
                $referralOfferInfos['slaveOfferValue'] = $offerInfos->slaveOffer->offerValue;
            }
        }
        return $referralOfferInfos;
    }

    public function getStats() {
        $json = $this->endpoint->doAuthRequest('getStats');
        if($json) {
            $decode = json_decode($json);
            return $decode->stats;
        }
        return null;
    }

    /*
     * Count codes remaining for offerId
     */

    public function countAvailableCodes($offerId, $codeType = false){
        $countAvailableCodesForOffer = false;
        $callData = array(
                            'offerId'       => $offerId,
                            'codeType'      => $codeType
                    );
        $response = $this->endpoint->doAuthRequest('countAvailableCodesForOffer', $callData); // getting count of codes for this offer in wlc database

        if ($response){
                $countAvailableCodesForOffer = json_decode($response);
                $countAvailableCodesForOffer = $countAvailableCodesForOffer->nbCodes;
        }else{
            $countAvailableCodesForOffer = '';
        }
        return $countAvailableCodesForOffer;
    }

    
    /*
     * Getting customer's NPS score
     */
    public function nps(){
        $scoreNPS = false;
        $response = $this->endpoint->doAuthRequest('getNPS'); // getting NPS score for this customer
        if ($response){
            $scoreNPS = json_decode($response);
            $scoreNPS = $scoreNPS->score;
        } else{
            $scoreNPS = '';
        }
        return $scoreNPS;
    }
}
